==> shell-0.1.0-sources.jar: io/github/qsy7/remote/plugins/shell/SystemActionMessageHandlerService.java <==
package io.github.qsy7.remote.plugins.shell;

// import io.github.qsy7.queuedJob.api.model.JobExecution;
// import io.github.qsy7.queue.api.queuedJob.CallableJob;

import io.github.qsy7.remote.api.service.MessageWriterService;
import io.github.qsy7.remote.impl.handler.AbstractMessageHandler;
import io.github.qsy7.shell.api.service.ShellExecutionService;
import javax.inject.Inject;

public class SystemActionMessageHandlerService extends AbstractMessageHandler
/*implements CallableJob<SystemActionMessage, Void>*/ {
  protected final ShellExecutionService shellExecutionService;

  protected SystemActionMessage systemActionMessage;

  @Inject
  public SystemActionMessageHandlerService(
      MessageWriterService messageWriterService, ShellExecutionService shellExecutionService) {
    super(messageWriterService);
    this.shellExecutionService = shellExecutionService;
  }

  //  @Override
  //  public void onSuccess() {}
  //
  //  @Override
  //  public void onError(Throwable thrown) {}
  //
  //  @Override
  //  public void setJobExecution(JobExecution jobExecution) {}
  //
  //  @Override
  //  public void setEntity(SystemActionMessage entity) {
  //    this.systemActionMessage = entity;
  //  }
  //
  //  @Override
  //  public SystemActionMessage getEntity() {
  //    return systemActionMessage;
  //  }
  //
  //  @Override
  //  public Void call() throws Exception {
  //    ShellCommand shellCommand =
  //        new ShellCommand()
  //            .withCommandLine("sudo " + systemActionMessage.getSystemAction())
  //            .withTimeout(10);
  //    shellExecutionService.run(shellCommand);
  //
  //    return (null);
  //  }
}

==> shell-0.3.1-sources.jar: io/github/qsy7/remote/plugins/shell/SystemActionMessageHandlerService.java <==
package io.github.qsy7.remote.plugins.shell;

// import io.github.qsy7.queuedJob.api.model.JobExecution;
// import io.github.qsy7.queue.api.queuedJob.CallableJob;

import io.github.qsy7.remote.api.service.MessageWriterService;
import io.github.qsy7.remote.impl.handler.AbstractMessageHandler;
import io.github.qsy7.shell.api.service.ShellExecutionService;
import jakarta.inject.Inject;

public class SystemActionMessageHandlerService extends AbstractMessageHandler
/*implements CallableJob<SystemActionMessage, Void>*/ {
  protected final ShellExecutionService shellExecutionService;

  protected SystemActionMessage systemActionMessage;

  @Inject
  public SystemActionMessageHandlerService(
      MessageWriterService messageWriterService, ShellExecutionService shellExecutionService) {
    super(messageWriterService);
    this.shellExecutionService = shellExecutionService;
  }

  //  @Override
  //  public void onSuccess() {}
  //
  //  @Override
  //  public void onError(Throwable thrown) {}
  //
  //  @Override
  //  public void setJobExecution(JobExecution jobExecution) {}
  //
  //  @Override
  //  public void setEntity(SystemActionMessage entity) {
  //    this.systemActionMessage = entity;
  //  }
  //
  //  @Override
  //  public SystemActionMessage getEntity() {
  //    return systemActionMessage;
  //  }
  //
  //  @Override
  //  public Void call() throws Exception {
  //    ShellCommand shellCommand =
  //        new ShellCommand()
  //            .withCommandLine("sudo " + systemActionMessage.getSystemAction())
  //            .withTimeout(10);
  //    shellExecutionService.run(shellCommand);
  //
  //    return (null);
  //  }
}
